@@ -31,7 +31,7 @@
 #include <KNS3/KMoreToolsMenuFactory>
 
 #include "SpectacleCommon.h"
-#include "SpectacleConfig.h"
+
 #include "KSWidget.h"
 #include "ExportMenu.h"
 #include "Platforms/Platform.h"
@@ -97,6 +97,7 @@ class KSMainWindow: public QDialog
     private:
 
     void keyPressEvent(QKeyEvent *event) override;
+    void copy();
 
     KSWidget         *mKSWidget;
     QFrame           *mDivider;
