@@ -35,9 +35,11 @@ class QFormLayout;
 class QComboBox;
 class QCheckBox;
 class QLabel;
-class QToolButton;
+
+class KConfigDialogManager;
 
 class KSImageWidget;
+class ProgressButton;
 class SmartSpinBox;
 
 class KSWidget : public QWidget
@@ -49,6 +51,7 @@ class KSWidget : public QWidget
     explicit KSWidget(const Platform::GrabModes &theGrabModes, QWidget *parent = nullptr);
     virtual ~KSWidget() = default;
 
+
     enum class State {
         TakeNewScreenshot,
         Cancel
@@ -68,6 +71,7 @@ class KSWidget : public QWidget
     void lockOnClickDisabled();
     void lockOnClickEnabled();
     void setButtonState(State state);
+    void setProgress(double progress);
 
     private Q_SLOTS:
 
@@ -83,7 +87,7 @@ class KSWidget : public QWidget
     QFormLayout   *mCaptureModeForm              { nullptr };
     QVBoxLayout   *mContentOptionsForm           { nullptr };
     KSImageWidget *mImageWidget                  { nullptr };
-    QToolButton   *mTakeScreenshotButton;
+    ProgressButton*mTakeScreenshotButton;
     QComboBox     *mCaptureArea                  { nullptr };
     SmartSpinBox  *mDelayMsec                    { nullptr };
     QCheckBox     *mCaptureOnClick               { nullptr };
@@ -96,4 +100,5 @@ class KSWidget : public QWidget
     bool           mTransientWithParentAvailable { false };
     QAction       *mTakeNewScreenshotAction;
     QAction       *mCancelAction;
+    KConfigDialogManager *mConfigManager;
 };
